@@ -20,11 +20,15 @@
 
 /**
  * SECTION:anjuta-session
- * @short_description: Program session
+ * @short_description: Store local user settings
  * @see_also:
  * @stability: Unstable
  * @include: libanjuta/anjuta-session.h
  *
+ * A anjuta session contains local user settings, by example the list of files
+ * open in one project. These settings are stored in
+ * a .ini-like config file in a directory named session. Other libraries can
+ * store their own settings in another format in the same directory.
  */
 
 #include <stdlib.h>
@@ -166,7 +170,6 @@ anjuta_session_clear (AnjutaSession *session)
 {
 	gchar *cmd;
 	gchar *quoted;
-	gint ret;
 
 	g_return_if_fail (ANJUTA_IS_SESSION (session));
 
@@ -177,11 +180,11 @@ anjuta_session_clear (AnjutaSession *session)
 
 	quoted = g_shell_quote (session->priv->dir_path);
 	cmd = g_strconcat ("rm -fr ", quoted, NULL);
-	ret = system (cmd);
+	system (cmd);
 	g_free (cmd);
 
 	cmd = g_strconcat ("mkdir -p ", quoted, NULL);
-	ret = system (cmd);
+	system (cmd);
 	g_free (cmd);
 	g_free (quoted);
 }
