@@ -43,6 +43,11 @@
 #include <string.h>
 #include <ctype.h>
 
+/* Types
+ *---------------------------------------------------------------------------*/
+
+G_DEFINE_DYNAMIC_TYPE (AmpGroupNode, amp_group_node, AMP_TYPE_NODE);
+
 
 /* Helper functions
  *---------------------------------------------------------------------------*/
@@ -341,7 +346,7 @@ on_group_monitor_changed (GFileMonitor *monitor,
 	}
 }
 
-void
+static void
 amp_group_node_update_preset_variable (AmpGroupNode *group)
 {
 	gchar *path;
@@ -673,6 +678,9 @@ amp_group_node_save (AmpNode *group, AmpNode *parent, AmpProject *project, GErro
 	gboolean ok = TRUE;
 	GFile *directory;
 
+	/* Check if Makefile.am is missing, it happens in po directory by example */
+	if (AMP_GROUP_NODE (group)->makefile == NULL) return FALSE;
+	
 	/* Create directory */
 	directory = g_file_get_parent (AMP_GROUP_NODE (group)->makefile);
 	g_file_make_directory (directory, NULL, NULL);
@@ -711,6 +719,19 @@ amp_group_node_update (AmpNode *node, AmpNode *new_node)
 	return TRUE;
 }
 
+static AmpNode *
+amp_group_node_copy (AmpNode *old_node)
+{
+	AmpNode *new_node;
+	
+	new_node = AMP_NODE_CLASS (amp_group_node_parent_class)->copy (old_node);
+	amp_group_node_add_token (AMP_GROUP_NODE (new_node), amp_group_node_get_first_token (AMP_GROUP_NODE (old_node), AM_GROUP_TOKEN_CONFIGURE), AM_GROUP_TOKEN_CONFIGURE);
+	amp_group_node_add_token (AMP_GROUP_NODE (new_node), amp_group_node_get_first_token (AMP_GROUP_NODE (old_node), AM_GROUP_TOKEN_SUBDIRS), AM_GROUP_TOKEN_SUBDIRS);
+	amp_group_node_add_token (AMP_GROUP_NODE (new_node), amp_group_node_get_first_token (AMP_GROUP_NODE (old_node), AM_GROUP_TOKEN_DIST_SUBDIRS), AM_GROUP_TOKEN_DIST_SUBDIRS);
+
+	return new_node;
+}
+
 static gboolean
 amp_group_node_write (AmpNode *node, AmpNode *parent, AmpProject *project, GError **error)
 {
@@ -728,9 +749,6 @@ amp_group_node_erase (AmpNode *node, AmpNode *parent, AmpProject *project, GErro
 /* GObjet implementation
  *---------------------------------------------------------------------------*/
 
-
-G_DEFINE_DYNAMIC_TYPE (AmpGroupNode, amp_group_node, AMP_TYPE_NODE);
-
 static void
 amp_group_node_init (AmpGroupNode *node)
 {
@@ -794,6 +812,7 @@ amp_group_node_class_init (AmpGroupNodeClass *klass)
 	node_class->load = amp_group_node_load;
 	node_class->save = amp_group_node_save;
 	node_class->update = amp_group_node_update;
+	node_class->copy = amp_group_node_copy;
 	node_class->write = amp_group_node_write;
 	node_class->erase = amp_group_node_erase;
 }
