@@ -296,17 +296,9 @@ on_log_command_finished (AnjutaCommand *command, guint return_code,
 		git_pane_report_errors (command, return_code,
 		                        ANJUTA_PLUGIN_GIT (anjuta_dock_pane_get_plugin (ANJUTA_DOCK_PANE (self))));
 #endif
-		g_object_ref (self->priv->log_model);
-		gtk_tree_view_set_model (GTK_TREE_VIEW (log_view), NULL);
-		g_object_unref (command);
-		
-		return;
+		goto out;
 	}
 	
-	
-	g_object_ref (self->priv->log_model);
-	gtk_tree_view_set_model (GTK_TREE_VIEW (log_view), NULL);
-	
 	queue = git_log_command_get_output_queue (GIT_LOG_COMMAND (command));
 	
 	while (g_queue_peek_head (queue))
@@ -325,8 +317,8 @@ on_log_command_finished (AnjutaCommand *command, guint return_code,
 										  0);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (log_view), 
 							 GTK_TREE_MODEL (self->priv->log_model));
-	g_object_unref (self->priv->log_model);
-	
+
+out:
 	g_clear_object (&self->priv->log_command);
 }
 
@@ -334,9 +326,12 @@ static void
 refresh_log (GitLogPane *self)
 {
 	Git *plugin;
+	GtkTreeView *log_view;
 	GtkTreeViewColumn *graph_column;
 
 	plugin = ANJUTA_PLUGIN_GIT (anjuta_dock_pane_get_plugin (ANJUTA_DOCK_PANE (self)));
+	log_view = GTK_TREE_VIEW (gtk_builder_get_object (self->priv->builder,
+	                                                  "log_view"));
 	graph_column = GTK_TREE_VIEW_COLUMN (gtk_builder_get_object (self->priv->builder,
 	                                                             "graph_column"));
 
@@ -344,6 +339,8 @@ refresh_log (GitLogPane *self)
 	if (self->priv->log_command)
 		g_object_unref (self->priv->log_command);
 
+	gtk_tree_view_set_model (log_view, NULL);
+
 	/* We don't support filters for now */
 	self->priv->log_command = git_log_command_new (plugin->project_root_directory,
 	                                               self->priv->selected_branch,
@@ -362,9 +359,9 @@ refresh_log (GitLogPane *self)
 	else
 		gtk_tree_view_column_set_visible (graph_column, TRUE);
 
-	g_signal_connect (G_OBJECT (self->priv->log_command), "command-finished",
-	                  G_CALLBACK (on_log_command_finished),
-	                  self);
+	g_signal_connect_object (G_OBJECT (self->priv->log_command), "command-finished",
+	                         G_CALLBACK (on_log_command_finished),
+	                         self, 0);
 
 	gtk_list_store_clear (self->priv->log_model);
 
@@ -396,17 +393,17 @@ on_ref_command_finished (AnjutaCommand *command, guint return_code,
 		git_branch_list_command_new (plugin->project_root_directory,
 		                             GIT_BRANCH_TYPE_ALL);
 
-	g_signal_connect (G_OBJECT (self->priv->branch_list_command), "command-started",
-	                  G_CALLBACK (on_branch_list_command_started),
-	                  self);
+	g_signal_connect_object (G_OBJECT (self->priv->branch_list_command), "command-started",
+	                         G_CALLBACK (on_branch_list_command_started),
+	                         self, 0);
 
-	g_signal_connect (G_OBJECT (self->priv->branch_list_command), "command-finished",
-	                  G_CALLBACK (on_branch_list_command_finished),
-	                  self);
+	g_signal_connect_object (G_OBJECT (self->priv->branch_list_command), "command-finished",
+	                         G_CALLBACK (on_branch_list_command_finished),
+	                         self, 0);
 
-	g_signal_connect (G_OBJECT (self->priv->branch_list_command), "data-arrived",
-	                  G_CALLBACK (on_branch_list_command_data_arrived),
-	                  self);
+	g_signal_connect_object (G_OBJECT (self->priv->branch_list_command), "data-arrived",
+	                         G_CALLBACK (on_branch_list_command_data_arrived),
+	                         self, 0);
 
 	anjuta_command_start (ANJUTA_COMMAND (self->priv->branch_list_command));
 }
@@ -665,9 +662,9 @@ on_log_view_row_selected (GtkTreeSelection *selection,
 		g_free (sha);
 		g_object_unref (revision);
 		
-		g_signal_connect (G_OBJECT (self->priv->log_message_command), "command-finished",
-						  G_CALLBACK (on_log_message_command_finished),
-						  self);
+		g_signal_connect_object (G_OBJECT (self->priv->log_message_command), "command-finished",
+		                         G_CALLBACK (on_log_message_command_finished),
+		                         self, 0);
 		
 		anjuta_command_start (ANJUTA_COMMAND (self->priv->log_message_command));
 	}
@@ -1018,6 +1015,7 @@ git_log_pane_finalize (GObject *object)
 		g_source_remove (self->priv->spin_timer_id);
 
 	g_object_unref (self->priv->builder);
+	g_object_unref (self->priv->log_model);
 	g_free (self->priv->path);
 	g_hash_table_destroy (self->priv->branches_table);
 
@@ -1064,9 +1062,9 @@ git_log_pane_new (Git *plugin)
 
 	self = g_object_new (GIT_TYPE_LOG_PANE, "plugin", plugin, NULL);
 
-	g_signal_connect (G_OBJECT (plugin->ref_command), "command-finished",
-	                  G_CALLBACK (on_ref_command_finished),
-	                  self);
+	g_signal_connect_object (G_OBJECT (plugin->ref_command), "command-finished",
+	                         G_CALLBACK (on_ref_command_finished),
+	                         self, 0);
 
 	return ANJUTA_DOCK_PANE (self);
 }
