@@ -420,8 +420,7 @@ add_entry (IAnjutaProject *project, AnjutaProjectNode *node, AnjutaProjectProper
 	}
 	gtk_misc_set_alignment (GTK_MISC (label), 0, -1);
 	gtk_widget_show (label);
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, *position, *position+1,
-			  GTK_FILL, GTK_FILL, 5, 3);
+	gtk_grid_attach (GTK_GRID (table), label, 0, *position, 1, 1);
 
 	switch (prop->info->type)
 	{
@@ -511,9 +510,9 @@ add_entry (IAnjutaProject *project, AnjutaProjectNode *node, AnjutaProjectProper
 	}
 	g_free (tooltip);
 
+	gtk_widget_set_hexpand (entry, TRUE);
+	gtk_grid_attach (GTK_GRID (table), entry, 1, *position, 1, 1);
 	gtk_widget_show (entry);
-	gtk_table_attach (GTK_TABLE (table), entry, 1, 2, *position, *position+1,
-			  GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 3);
 
 	*position = *position + 1;
 
@@ -528,14 +527,13 @@ add_label (const gchar *display_name, const gchar *value, GtkWidget *table, gint
 	label = gtk_label_new (display_name);
 	gtk_misc_set_alignment (GTK_MISC (label), 0, -1);
 	gtk_widget_show (label);
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, *position, *position+1,
-			  GTK_FILL, GTK_FILL, 5, 3);
+	gtk_grid_attach (GTK_GRID (table), label, 0, *position, 1, 1);
 
 	label = gtk_label_new (value);
 	gtk_misc_set_alignment (GTK_MISC (label), 0, -1);
+	gtk_widget_set_hexpand (label, TRUE);
 	gtk_widget_show (label);
-	gtk_table_attach (GTK_TABLE (table), label, 1, 2, *position, *position+1,
-			  GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 3);
+	gtk_grid_attach (GTK_GRID (table), label, 1, *position, 1, 1);
 
 	*position = *position + 1;
 }
@@ -549,14 +547,12 @@ add_button (const gchar *display_name, const gchar *value, GCallback on_clicked,
 	label = gtk_label_new (display_name);
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_widget_show (label);
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, *position, *position+1,
-			  GTK_FILL, GTK_FILL, 5, 3);
+	gtk_grid_attach (GTK_GRID (table), label, 0, *position, 1, 1);
 
 	button = gtk_button_new_with_label (value);
 	gtk_button_set_alignment (GTK_BUTTON (button), 0, 0.5);
 	gtk_widget_show (button);
-	gtk_table_attach (GTK_TABLE (table), button, 1, 2, *position, *position+1,
-			  GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 3);
+	gtk_grid_attach (GTK_GRID (table), button, 1, *position, 1, 1);
 	if (on_clicked != NULL)
 	{
 		g_signal_connect (G_OBJECT (button), "clicked", on_clicked, properties);
@@ -570,7 +566,7 @@ pm_project_resize_properties_dialog (PropertiesTable *table)
 {
 	gint border_width, maximum_width, maximum_height;
 	GtkRequisition dialog, head, viewport, scrolledwindow_minimum, vscrollbar_minimum;
-	GtkWidget *vscrollbar = gtk_scrolled_window_get_vscrollbar (table->scrolledwindow);
+	GtkWidget *vscrollbar = gtk_scrolled_window_get_vscrollbar (GTK_SCROLLED_WINDOW (table->scrolledwindow));
 
 	gtk_widget_get_preferred_size (table->dialog, NULL, &dialog);
 	gtk_widget_get_preferred_size (table->head, NULL, &head);
@@ -659,9 +655,10 @@ on_change_project_backend (GtkButton *button,
 
 		if (backend != NULL)
 		{
-			const gchar *name;
+			gchar *name;
 			anjuta_plugin_description_get_locale_string (backend, "Anjuta Plugin", "Name", &name);
 			gtk_button_set_label (button, name);
+			g_free (name);
 			table->new_backend = backend;
 		}
 	}
@@ -742,10 +739,11 @@ update_properties (PropertiesTable *table)
 		backend = anjuta_pm_project_get_backend (table->project);
 		if (backend)
 		{
-			const gchar *name;
+			gchar *name;
 			
 			anjuta_plugin_description_get_locale_string (backend, "Anjuta Plugin", "Name", &name);
-			add_button (_("Backend:"), name, on_change_project_backend, table, table->head, &head_pos);
+			add_button (_("Backend:"), name, G_CALLBACK (on_change_project_backend), table, table->head, &head_pos);
+			g_free (name);
 		}
 	}
 
@@ -1179,7 +1177,7 @@ anjuta_pm_project_new_group (ProjectManagerPlugin *plugin, GtkWindow *parent, Gt
 				name = gtk_editable_get_chars (
 						GTK_EDITABLE (group_name_entry), 0, -1);
 
-				group = gbf_project_view_find_selected_state (GBF_PROJECT_VIEW (groups_view),
+				group = gbf_project_view_find_selected_state (GTK_TREE_VIEW (groups_view),
 				                                              ANJUTA_PROJECT_CAN_ADD_GROUP);
 				if (group)
 				{
@@ -1808,10 +1806,13 @@ static void
 on_new_library(GtkButton *button, gpointer user_data)
 {
 	ProjectManagerPlugin *plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (user_data);
-	anjuta_pm_project_new_package (plugin,
-	                               get_plugin_parent_window (plugin),
-	                               NULL,
-	                               NULL);
+	GList *packages;
+	
+	packages = anjuta_pm_project_new_package (plugin,
+	                                          get_plugin_parent_window (plugin),
+	                                          NULL,
+	                                          NULL);
+	g_list_free (packages);
 }
 
 GList*
